@@ -110,12 +110,17 @@ def Csys(
     if isinstance(ps.unit, str):
         ps.unit = udict[ps.unit]
 
-    if ps.unit != 1:
-        upar = ["DIC", "TA", "CO2", "HCO3", "CO3", "BT", "fCO2", "pCO2", "TP", "TSi"]
+    upar = ["DIC", "TA", "CO2", "HCO3", "CO3", "BT", "TP", "TSi"]
+    if ps.unit != 1:    
         for p in upar:
             if ps[p] is not None:
                 ps[p] = np.divide(ps[p], ps.unit)  # convert to molar
     
+    gupar = ['pCO2', 'fCO2']  # special unit case: pCO2, fCO2 because pCO2 is always in ppm
+    for p in gupar:
+        if ps[p] is not None:
+            ps[p] = np.divide(ps[p], 1e6)  # convert to mole fraction
+    
     # Conserved seawater chemistry
     if ps.TS is None:
         ps.TS = calc_TS(ps.S_in)
@@ -170,8 +175,8 @@ def Csys(
         oCa = 0.0102821 * ps.S_in / 35.
     else:
         oCa = Ca * ps.S_in / 35.
-    ps['OmegaA'] = ps['CO3'] / ps.unit * oCa / ps.Ks.KspA
-    ps['OmegaC'] = ps['CO3'] / ps.unit * oCa / ps.Ks.KspA
+    ps['OmegaA'] = ps['CO3'] * oCa / ps.Ks.KspA
+    ps['OmegaC'] = ps['CO3'] * oCa / ps.Ks.KspC
 
     # clean up output
     outputs = [
@@ -185,6 +190,8 @@ def Csys(
     if ps.unit != 1:
         for p in upar + ["CAlk", "BAlk", "PAlk", "SiAlk", "OH", "HSO4", "HF", "Hfree"]:
             ps[p] *= ps.unit  # convert back to input units
+        for p in gupar:
+            ps[p] = np.multiply(ps[p], 1e6)  # convert to ppm
 
     # Calculate Output Conditions
     # ===========================
@@ -707,18 +714,22 @@ def CBsys(
         "HCO3",
         "CO3",
         "TA",
-        "fCO2",
-        "pCO2",
         "BT",
         "BO3",
         "BO4",
         "TP",
         "TSi",
     ]
+ 
     for p in upar:
         if ps[p] is not None:
             ps[p] = np.divide(ps[p], ps.unit)  # convert to molar
 
+    gupar = ['pCO2', 'fCO2']  # special unit case: pCO2, fCO2 because pCO2 is always in ppm
+    for p in gupar:
+        if ps[p] is not None:
+            ps[p] = np.divide(ps[p], 1e6)  # convert to mole fraction
+    
     # Conserved seawater chemistry
     if ps.TS is None:
         ps.TS = calc_TS(ps.S_in)
@@ -836,8 +847,8 @@ def CBsys(
         oCa = 0.0102821 * ps.S_in / 35.
     else:
         oCa = Ca * ps.S_in / 35.
-    ps['OmegaA'] = ps['CO3'] / ps.unit * oCa / ps.Ks.KspA
-    ps['OmegaC'] = ps['CO3'] / ps.unit * oCa / ps.Ks.KspA
+    ps['OmegaA'] = ps['CO3'] * oCa / ps.Ks.KspA
+    ps['OmegaC'] = ps['CO3'] * oCa / ps.Ks.KspC
     
     # clean up output
     outputs = [
@@ -884,10 +895,14 @@ def CBsys(
             # convert all outputs to (min) 1D numpy arrays.
             ps[k] = np.array(ps[k], ndmin=1)
 
-    # Handle Units
+    # Handle Units - at this point everything is in mol/kg-SW
     for p in upar + ["CAlk", "BAlk", "PAlk", "SiAlk", "OH", "HSO4", "HF", "Hfree"]:
         ps[p] *= ps.unit  # convert back to input units
 
+    for p in gupar:
+        if ps[p] is not None:
+            ps[p] = np.multiply(ps[p], 1e6)  # convert to ppm
+
     # Calculate Output Conditions
     # ===========================
     
