@@ -405,30 +405,3 @@ def pH_scale_converter(pH, scale, Temp, Sal, Press=None, TS=None, TF=None):
     inp[np.argwhere(scale == np.array(pH_scales))[0, 0]] = pH
 
     return calc_pH_scales(*inp, TS, TF, TempK, Sal, Ks)
-
-
-# TODO: function that correct pH for temperature
-def calc_pH_Tcorr(pH, T, T_ref, scale, Sal, Press=None, TS=None, TF=None):
-    """
-    Returns pH on all scales.
-    """
-    pH_scales = ["Total", "FREE", "SWS", "NBS"]
-    if scale not in pH_scales:
-        raise ValueError("scale must be one of Total, NBS, SWS or FREE.")
-    if TS is None:
-        TS = calc_TS(Sal)
-    if TF is None:
-        TF = calc_TF(Sal)
-    TempK = T + 273.15
-    TempK_ref = T_ref + 273.15
-
-    # Ks = kgen.calc_Ks(TempC=T, Sal=Sal, Pres=Press)
-    # Ks_ref = kgen.calc_Ks(TempC=T_ref, Sal=Sal, Pres=Press)
-
-    # inp = [None, None, None, None]
-    # inp[np.argwhere(scale == np.array(pH_scales))[0, 0]] = pH
-
-    # pH_dict = calc_pH_scales(*inp, TS, TF, TempK, Sal, Ks)
-    # pH_dict_ref = calc_pH_scales(*inp, TS, TF, TempK_ref, Sal, Ks_ref)
-
-    # return pH_dict, pH_dict_ref
\ No newline at end of file
